#[non_exhaustive]pub enum UdfError {
Registration(String),
DataFusion(DataFusionError),
RemoteDisabled,
Manifest(ManifestError),
Transport(TransportError),
}Expand description
Errors surfaced by the crate’s registration entry points.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Registration(String)
A UDF could not be registered on the session context.
DataFusion(DataFusionError)
An error propagated from DataFusion.
RemoteDisabled
A manifest_path was supplied but the remote feature is not enabled.
Manifest(ManifestError)
The remote manifest was invalid.
Transport(TransportError)
A remote service could not be connected at startup.